@@ -1,5 +1,5 @@
 package Clipboard;
-$Clipboard::VERSION = '0.15';
+$Clipboard::VERSION = '0.16';
 our $driver;
 
 sub copy { my $self = shift; $driver->copy(@_); }
@@ -15,8 +15,8 @@ sub find_driver {
         # example, cygwin doesn't count as Unix here, because it will
         # use the Win32 clipboard.)
         bind_os(Xclip => qw(linux bsd$ aix bsdos dec_osf dgux
-            dynixptx hpux irix dragonfly machten next os2 sco_sv solaris sunos
-            svr4 svr5 unicos unicosmk)),
+            dynixptx gnu hpux irix dragonfly machten next os2 sco_sv solaris
+            sunos svr4 svr5 unicos unicosmk)),
         bind_os(MacPasteboard => qw(darwin)),
         bind_os(Win32 => qw(mswin ^win cygwin)),
     );
@@ -46,7 +46,7 @@ Clipboard
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -79,7 +79,7 @@ Clipboard - Copy and paste with any OS
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 STATUS
 
